@@ -2,6 +2,7 @@
 from luckydonaldUtils.encoding import unicode_type, to_unicode as u
 from luckydonaldUtils.exceptions import assert_type_or_raise
 from . import Sendable
+from .files import InputFile
 
 __author__ = 'luckydonald'
 __all__ = [
@@ -35,13 +36,14 @@ class InputMedia(Sendable):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
@@ -63,13 +65,14 @@ class InputMedia(Sendable):
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMedia, self).__init__()
@@ -122,7 +125,6 @@ class InputMedia(Sendable):
         if self.caption_entities is not None:
             array['caption_entities'] = self._as_array(self.caption_entities)  # type list of MessageEntity
         # end if
-
         return array
     # end def to_array
 
@@ -251,13 +253,14 @@ class InputMediaWithThumb(InputMedia):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
@@ -314,13 +317,14 @@ class InputMediaWithThumb(InputMedia):
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMediaWithThumb, self).__init__(type=type, media=media, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
@@ -446,13 +450,14 @@ class InputMediaPlayable(InputMediaWithThumb):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
@@ -483,13 +488,14 @@ class InputMediaPlayable(InputMediaWithThumb):
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMediaPlayable, self).__init__(type=type, media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
@@ -528,7 +534,6 @@ class InputMediaPlayable(InputMediaWithThumb):
         # 'caption' given by superclass
         # 'parse_mode' given by superclass
         # 'caption_entities' given by superclass
-
         return array
     # end def to_array
 
@@ -632,13 +637,14 @@ class InputMediaVideolike(InputMediaPlayable):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
@@ -675,13 +681,14 @@ class InputMediaVideolike(InputMediaPlayable):
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the media to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMediaVideolike, self).__init__(type=type, media=media, thumb=thumb, duration=duration, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
@@ -727,7 +734,6 @@ class InputMediaVideolike(InputMediaPlayable):
         # 'caption' given by superclass
         # 'parse_mode' given by superclass
         # 'caption_entities' given by superclass
-
         return array
     # end def to_array
 
@@ -818,13 +824,14 @@ class InputMediaPhoto(InputMedia):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
     """
 
@@ -844,13 +851,14 @@ class InputMediaPhoto(InputMedia):
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the photo caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
         """
         super(InputMediaPhoto, self).__init__(type='photo', media=media, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
@@ -884,7 +892,6 @@ class InputMediaPhoto(InputMedia):
         # 'caption' given by superclass
         # 'parse_mode' given by superclass
         # 'caption_entities' given by superclass
-
         return array
     # end def to_array
 
@@ -970,28 +977,34 @@ class InputMediaVideo(InputMediaVideolike):
 
     Optional keyword parameters:
 
-    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                  The thumbnail should be in JPEG format and less than 200 kB in size.
+                  A thumbnail's width and height should not exceed 320.
+                  Ignored if the file is not uploaded using multipart/form-data.
+                  Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                  More info on Sending Files ».
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the video to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the video caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the video caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-    :param width: Optional. Video width
+    :param width: Optional. Video width.
     :type  width: int
 
-    :param height: Optional. Video height
+    :param height: Optional. Video height.
     :type  height: int
 
-    :param duration: Optional. Video duration
+    :param duration: Optional. Video duration in seconds.
     :type  duration: int
 
-    :param supports_streaming: Optional. Pass True, if the uploaded video is suitable for streaming
+    :param supports_streaming: Optional. Pass True, if the uploaded video is suitable for streaming.
     :type  supports_streaming: bool
     """
 
@@ -1011,28 +1024,34 @@ class InputMediaVideo(InputMediaVideolike):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                      The thumbnail should be in JPEG format and less than 200 kB in size.
+                      A thumbnail's width and height should not exceed 320.
+                      Ignored if the file is not uploaded using multipart/form-data.
+                      Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                      More info on Sending Files ».
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the video to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the video caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the video caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-        :param width: Optional. Video width
+        :param width: Optional. Video width.
         :type  width: int
 
-        :param height: Optional. Video height
+        :param height: Optional. Video height.
         :type  height: int
 
-        :param duration: Optional. Video duration
+        :param duration: Optional. Video duration in seconds.
         :type  duration: int
 
-        :param supports_streaming: Optional. Pass True, if the uploaded video is suitable for streaming
+        :param supports_streaming: Optional. Pass True, if the uploaded video is suitable for streaming.
         :type  supports_streaming: bool
         """
         super(InputMediaVideo, self).__init__(type='video', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, width=width, height=height, duration=duration)
@@ -1081,7 +1100,6 @@ class InputMediaVideo(InputMediaVideolike):
         if self.supports_streaming is not None:
             array['supports_streaming'] = bool(self.supports_streaming)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -1173,25 +1191,31 @@ class InputMediaAnimation(InputMediaVideolike):
 
     Optional keyword parameters:
 
-    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                  The thumbnail should be in JPEG format and less than 200 kB in size.
+                  A thumbnail's width and height should not exceed 320.
+                  Ignored if the file is not uploaded using multipart/form-data.
+                  Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                  More info on Sending Files ».
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the animation caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the animation caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-    :param width: Optional. Animation width
+    :param width: Optional. Animation width.
     :type  width: int
 
-    :param height: Optional. Animation height
+    :param height: Optional. Animation height.
     :type  height: int
 
-    :param duration: Optional. Animation duration
+    :param duration: Optional. Animation duration in seconds.
     :type  duration: int
     """
 
@@ -1211,25 +1235,31 @@ class InputMediaAnimation(InputMediaVideolike):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                      The thumbnail should be in JPEG format and less than 200 kB in size.
+                      A thumbnail's width and height should not exceed 320.
+                      Ignored if the file is not uploaded using multipart/form-data.
+                      Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                      More info on Sending Files ».
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the animation caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the animation caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-        :param width: Optional. Animation width
+        :param width: Optional. Animation width.
         :type  width: int
 
-        :param height: Optional. Animation height
+        :param height: Optional. Animation height.
         :type  height: int
 
-        :param duration: Optional. Animation duration
+        :param duration: Optional. Animation duration in seconds.
         :type  duration: int
         """
         super(InputMediaAnimation, self).__init__(type='animation', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, width=width, height=height, duration=duration)
@@ -1273,7 +1303,6 @@ class InputMediaAnimation(InputMediaVideolike):
         # 'width' given by superclass
         # 'height' given by superclass
         # 'duration' given by superclass
-
         return array
     # end def to_array
 
@@ -1364,25 +1393,31 @@ class InputMediaAudio(InputMediaPlayable):
 
     Optional keyword parameters:
 
-    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                  The thumbnail should be in JPEG format and less than 200 kB in size.
+                  A thumbnail's width and height should not exceed 320.
+                  Ignored if the file is not uploaded using multipart/form-data.
+                  Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                  More info on Sending Files ».
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the audio caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the audio caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-    :param duration: Optional. Duration of the audio in seconds
+    :param duration: Optional. Duration of the audio in seconds.
     :type  duration: int
 
-    :param performer: Optional. Performer of the audio
+    :param performer: Optional. Performer of the audio.
     :type  performer: str|unicode
 
-    :param title: Optional. Title of the audio
+    :param title: Optional. Title of the audio.
     :type  title: str|unicode
     """
 
@@ -1402,25 +1437,31 @@ class InputMediaAudio(InputMediaPlayable):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                      The thumbnail should be in JPEG format and less than 200 kB in size.
+                      A thumbnail's width and height should not exceed 320.
+                      Ignored if the file is not uploaded using multipart/form-data.
+                      Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                      More info on Sending Files ».
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the audio caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the audio caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-        :param duration: Optional. Duration of the audio in seconds
+        :param duration: Optional. Duration of the audio in seconds.
         :type  duration: int
 
-        :param performer: Optional. Performer of the audio
+        :param performer: Optional. Performer of the audio.
         :type  performer: str|unicode
 
-        :param title: Optional. Title of the audio
+        :param title: Optional. Title of the audio.
         :type  title: str|unicode
         """
         super(InputMediaAudio, self).__init__(type='audio', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities, duration=duration)
@@ -1470,7 +1511,6 @@ class InputMediaAudio(InputMediaPlayable):
         if self.title is not None:
             array['title'] = u(self.title)  # py2: type unicode, py3: type str
         # end if
-
         return array
     # end def to_array
 
@@ -1561,19 +1601,26 @@ class InputMediaDocument(InputMediaWithThumb):
 
     Optional keyword parameters:
 
-    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                  The thumbnail should be in JPEG format and less than 200 kB in size.
+                  A thumbnail's width and height should not exceed 320.
+                  Ignored if the file is not uploaded using multipart/form-data.
+                  Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                  More info on Sending Files ».
     :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
+    :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing.
     :type  caption: str|unicode
 
-    :param parse_mode: Optional. Mode for parsing entities in the document caption. See formatting options for more details.
+    :param parse_mode: Optional. Mode for parsing entities in the document caption.
+                       See formatting options for more details.
     :type  parse_mode: str|unicode
 
-    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+    :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
     :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-    :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data. Always true, if the document is sent as part of an album.
+    :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data.
+                                           Always True, if the document is sent as part of an album.
     :type  disable_content_type_detection: bool
     """
 
@@ -1593,19 +1640,26 @@ class InputMediaDocument(InputMediaWithThumb):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side.
+                      The thumbnail should be in JPEG format and less than 200 kB in size.
+                      A thumbnail's width and height should not exceed 320.
+                      Ignored if the file is not uploaded using multipart/form-data.
+                      Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
+                      More info on Sending Files ».
         :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
+        :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing.
         :type  caption: str|unicode
 
-        :param parse_mode: Optional. Mode for parsing entities in the document caption. See formatting options for more details.
+        :param parse_mode: Optional. Mode for parsing entities in the document caption.
+                           See formatting options for more details.
         :type  parse_mode: str|unicode
 
-        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
+        :param caption_entities: Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode.
         :type  caption_entities: list of pytgbot.api_types.receivable.media.MessageEntity
 
-        :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data. Always true, if the document is sent as part of an album.
+        :param disable_content_type_detection: Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data.
+                                               Always True, if the document is sent as part of an album.
         :type  disable_content_type_detection: bool
         """
         super(InputMediaDocument, self).__init__(type='document', media=media, thumb=thumb, caption=caption, parse_mode=parse_mode, caption_entities=caption_entities)
@@ -1648,7 +1702,6 @@ class InputMediaDocument(InputMediaWithThumb):
         if self.disable_content_type_detection is not None:
             array['disable_content_type_detection'] = bool(self.disable_content_type_detection)  # type bool
         # end if
-
         return array
     # end def to_array
 
