@@ -59,17 +59,25 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
     Optional keyword parameters:
 
-    :param resize_keyboard: Optional. Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons). Defaults to false, in which case the custom keyboard is always of the same height as the app's standard keyboard.
+    :param resize_keyboard: Optional. Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons).
+                            Defaults to false, in which case the custom keyboard is always of the same height as the app's standard keyboard.
     :type  resize_keyboard: bool
 
-    :param one_time_keyboard: Optional. Requests clients to hide the keyboard as soon as it's been used. The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat – the user can press a special button in the input field to see the custom keyboard again. Defaults to false.
+    :param one_time_keyboard: Optional. Requests clients to hide the keyboard as soon as it's been used.
+                              The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat – the user can press a special button in the input field to see the custom keyboard again.
+                              Defaults to false.
     :type  one_time_keyboard: bool
 
-    :param selective: Optional. Use this parameter if you want to show the keyboard to specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user requests to change the bot's language, bot replies to the request with a keyboard to select the new language. Other users in the group don't see the keyboard.
+    :param input_field_placeholder: Optional. The placeholder to be shown in the input field when the keyboard is active; 1-64 characters.
+    :type  input_field_placeholder: str|unicode
+
+    :param selective: Optional. Use this parameter if you want to show the keyboard to specific users only.
+                      Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user requests to change the bot's language, bot replies to the request with a keyboard to select the new language.
+                      Other users in the group don't see the keyboard.
     :type  selective: bool
     """
 
-    def __init__(self, keyboard, resize_keyboard=None, one_time_keyboard=None, selective=None):
+    def __init__(self, keyboard, resize_keyboard=None, one_time_keyboard=None, input_field_placeholder=None, selective=None):
         """
         This object represents a custom keyboard with reply options (see Introduction to bots for details and examples).
 
@@ -84,13 +92,21 @@ class ReplyKeyboardMarkup(ReplyMarkup):
 
         Optional keyword parameters:
 
-        :param resize_keyboard: Optional. Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons). Defaults to false, in which case the custom keyboard is always of the same height as the app's standard keyboard.
+        :param resize_keyboard: Optional. Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons).
+                                Defaults to false, in which case the custom keyboard is always of the same height as the app's standard keyboard.
         :type  resize_keyboard: bool
 
-        :param one_time_keyboard: Optional. Requests clients to hide the keyboard as soon as it's been used. The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat – the user can press a special button in the input field to see the custom keyboard again. Defaults to false.
+        :param one_time_keyboard: Optional. Requests clients to hide the keyboard as soon as it's been used.
+                                  The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat – the user can press a special button in the input field to see the custom keyboard again.
+                                  Defaults to false.
         :type  one_time_keyboard: bool
 
-        :param selective: Optional. Use this parameter if you want to show the keyboard to specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user requests to change the bot's language, bot replies to the request with a keyboard to select the new language. Other users in the group don't see the keyboard.
+        :param input_field_placeholder: Optional. The placeholder to be shown in the input field when the keyboard is active; 1-64 characters.
+        :type  input_field_placeholder: str|unicode
+
+        :param selective: Optional. Use this parameter if you want to show the keyboard to specific users only.
+                          Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user requests to change the bot's language, bot replies to the request with a keyboard to select the new language.
+                          Other users in the group don't see the keyboard.
         :type  selective: bool
         """
         super(ReplyKeyboardMarkup, self).__init__()
@@ -100,6 +116,8 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         self.resize_keyboard = resize_keyboard
         assert_type_or_raise(one_time_keyboard, None, bool, parameter_name="one_time_keyboard")
         self.one_time_keyboard = one_time_keyboard
+        assert_type_or_raise(input_field_placeholder, None, unicode_type, parameter_name="input_field_placeholder")
+        self.input_field_placeholder = input_field_placeholder
         assert_type_or_raise(selective, None, bool, parameter_name="selective")
         self.selective = selective
     # end def __init__
@@ -127,10 +145,12 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         if self.one_time_keyboard is not None:
             array['one_time_keyboard'] = bool(self.one_time_keyboard)  # type bool
         # end if
+        if self.input_field_placeholder is not None:
+            array['input_field_placeholder'] = u(self.input_field_placeholder)  # py2: type unicode, py3: type str
+        # end if
         if self.selective is not None:
             array['selective'] = bool(self.selective)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -147,6 +167,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         data['keyboard'] = KeyboardButton.from_array_list(array.get('keyboard'), list_level=2)
         data['resize_keyboard'] = bool(array.get('resize_keyboard')) if array.get('resize_keyboard') is not None else None
         data['one_time_keyboard'] = bool(array.get('one_time_keyboard')) if array.get('one_time_keyboard') is not None else None
+        data['input_field_placeholder'] = u(array.get('input_field_placeholder')) if array.get('input_field_placeholder') is not None else None
         data['selective'] = bool(array.get('selective')) if array.get('selective') is not None else None
         return data
     # end def validate_array
@@ -173,7 +194,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         """
         Implements `str(replykeyboardmarkup_instance)`
         """
-        return "ReplyKeyboardMarkup(keyboard={self.keyboard!r}, resize_keyboard={self.resize_keyboard!r}, one_time_keyboard={self.one_time_keyboard!r}, selective={self.selective!r})".format(self=self)
+        return "ReplyKeyboardMarkup(keyboard={self.keyboard!r}, resize_keyboard={self.resize_keyboard!r}, one_time_keyboard={self.one_time_keyboard!r}, input_field_placeholder={self.input_field_placeholder!r}, selective={self.selective!r})".format(self=self)
     # end def __str__
 
     def __repr__(self):
@@ -183,7 +204,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         if self._raw:
             return "ReplyKeyboardMarkup.from_array({self._raw})".format(self=self)
         # end if
-        return "ReplyKeyboardMarkup(keyboard={self.keyboard!r}, resize_keyboard={self.resize_keyboard!r}, one_time_keyboard={self.one_time_keyboard!r}, selective={self.selective!r})".format(self=self)
+        return "ReplyKeyboardMarkup(keyboard={self.keyboard!r}, resize_keyboard={self.resize_keyboard!r}, one_time_keyboard={self.one_time_keyboard!r}, input_field_placeholder={self.input_field_placeholder!r}, selective={self.selective!r})".format(self=self)
     # end def __repr__
 
     def __contains__(self, key):
@@ -191,7 +212,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         Implements `"key" in replykeyboardmarkup_instance`
         """
         return (
-            key in ["keyboard", "resize_keyboard", "one_time_keyboard", "selective"]
+            key in ["keyboard", "resize_keyboard", "one_time_keyboard", "input_field_placeholder", "selective"]
             and hasattr(self, key)
             and bool(getattr(self, key, None))
         )
@@ -215,13 +236,16 @@ class KeyboardButton(Button):
 
     Optional keyword parameters:
 
-    :param request_contact: Optional. If True, the user's phone number will be sent as a contact when the button is pressed. Available in private chats only
+    :param request_contact: Optional. If True, the user's phone number will be sent as a contact when the button is pressed.
+                            Available in private chats only.
     :type  request_contact: bool
 
-    :param request_location: Optional. If True, the user's current location will be sent when the button is pressed. Available in private chats only
+    :param request_location: Optional. If True, the user's current location will be sent when the button is pressed.
+                             Available in private chats only.
     :type  request_location: bool
 
-    :param request_poll: Optional. If specified, the user will be asked to create a poll and send it to the bot when the button is pressed. Available in private chats only
+    :param request_poll: Optional. If specified, the user will be asked to create a poll and send it to the bot when the button is pressed.
+                         Available in private chats only.
     :type  request_poll: pytgbot.api_types.sendable.reply_markup.KeyboardButtonPollType
     """
 
@@ -241,13 +265,16 @@ class KeyboardButton(Button):
 
         Optional keyword parameters:
 
-        :param request_contact: Optional. If True, the user's phone number will be sent as a contact when the button is pressed. Available in private chats only
+        :param request_contact: Optional. If True, the user's phone number will be sent as a contact when the button is pressed.
+                                Available in private chats only.
         :type  request_contact: bool
 
-        :param request_location: Optional. If True, the user's current location will be sent when the button is pressed. Available in private chats only
+        :param request_location: Optional. If True, the user's current location will be sent when the button is pressed.
+                                 Available in private chats only.
         :type  request_location: bool
 
-        :param request_poll: Optional. If specified, the user will be asked to create a poll and send it to the bot when the button is pressed. Available in private chats only
+        :param request_poll: Optional. If specified, the user will be asked to create a poll and send it to the bot when the button is pressed.
+                             Available in private chats only.
         :type  request_poll: pytgbot.api_types.sendable.reply_markup.KeyboardButtonPollType
         """
         super(KeyboardButton, self).__init__()
@@ -287,7 +314,6 @@ class KeyboardButton(Button):
         if self.request_poll is not None:
             array['request_poll'] = self.request_poll.to_array()  # type KeyboardButtonPollType
         # end if
-
         return array
     # end def to_array
 
@@ -364,7 +390,9 @@ class KeyboardButtonPollType(Button):
 
     Optional keyword parameters:
 
-    :param type: Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.
+    :param type: Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode.
+                 If regular is passed, only regular polls will be allowed.
+                 Otherwise, the user will be allowed to create a poll of any type.
     :type  type: str|unicode
     """
 
@@ -376,7 +404,9 @@ class KeyboardButtonPollType(Button):
 
         Optional keyword parameters:
 
-        :param type: Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.
+        :param type: Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode.
+                     If regular is passed, only regular polls will be allowed.
+                     Otherwise, the user will be allowed to create a poll of any type.
         :type  type: str|unicode
         """
         super(KeyboardButtonPollType, self).__init__()
@@ -403,7 +433,6 @@ class KeyboardButtonPollType(Button):
         if self.type is not None:
             array['type'] = u(self.type)  # py2: type unicode, py3: type str
         # end if
-
         return array
     # end def to_array
 
@@ -481,7 +510,8 @@ class ReplyKeyboardRemove(ReplyMarkup):
 
     Optional keyword parameters:
 
-    :param selective: Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven't voted yet.
+    :param selective: Optional. Use this parameter if you want to remove the keyboard for specific users only.
+                      Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven't voted yet.
     :type  selective: bool
     """
 
@@ -535,7 +565,6 @@ class ReplyKeyboardRemove(ReplyMarkup):
         if self.selective is not None:
             array['selective'] = bool(self.selective)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -657,7 +686,6 @@ class InlineKeyboardMarkup(ReplyMarkup):
         array = super(InlineKeyboardMarkup, self).to_array()
 
         array['inline_keyboard'] = self._as_array(self.inline_keyboard)  # type list of list of InlineKeyboardButton
-
         return array
     # end def to_array
 
@@ -741,25 +769,32 @@ class InlineKeyboardButton(Button):
 
     Optional keyword parameters:
 
-    :param url: Optional. HTTP or tg:// url to be opened when button is pressed
+    :param url: Optional. HTTP or tg:// url to be opened when the button is pressed.
+                Links tg://user?id=<user_id> can be used to mention a user by their ID without using a username, if this is allowed by their privacy settings.
     :type  url: str|unicode
 
-    :param login_url: Optional. An HTTP URL used to automatically authorize the user. Can be used as a replacement for the Telegram Login Widget.
+    :param login_url: Optional. An HTTP URL used to automatically authorize the user.
+                      Can be used as a replacement for the Telegram Login Widget.
     :type  login_url: pytgbot.api_types.sendable.reply_markup.LoginUrl
 
-    :param callback_data: Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes
+    :param callback_data: Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes.
     :type  callback_data: str|unicode
 
-    :param switch_inline_query: Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field. Can be empty, in which case just the bot's username will be inserted.Note: This offers an easy way for users to start using your bot in inline mode when they are currently in a private chat with it. Especially useful when combined with switch_pm… actions – in this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
+    :param switch_inline_query: Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field.
+                                Can be empty, in which case just the bot's username will be inserted.Note: This offers an easy way for users to start using your bot in inline mode when they are currently in a private chat with it.
+                                Especially useful when combined with switch_pm… actions – in this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
     :type  switch_inline_query: str|unicode
 
-    :param switch_inline_query_current_chat: Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field. Can be empty, in which case only the bot's username will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat – good for selecting something from multiple options.
+    :param switch_inline_query_current_chat: Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field.
+                                             Can be empty, in which case only the bot's username will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat – good for selecting something from multiple options.
     :type  switch_inline_query_current_chat: str|unicode
 
-    :param callback_game: Optional. Description of the game that will be launched when the user presses the button.NOTE: This type of button must always be the first button in the first row.
+    :param callback_game: Optional. Description of the game that will be launched when the user presses the button.
+                          NOTE: This type of button must always be the first button in the first row.
     :type  callback_game: pytgbot.api_types.receivable.updates.CallbackGame
 
-    :param pay: Optional. Specify True, to send a Pay button.NOTE: This type of button must always be the first button in the first row.
+    :param pay: Optional. Specify True, to send a Pay button.
+                NOTE: This type of button must always be the first button in the first row and can only be used in invoice messages.
     :type  pay: bool
     """
 
@@ -778,25 +813,32 @@ class InlineKeyboardButton(Button):
 
         Optional keyword parameters:
 
-        :param url: Optional. HTTP or tg:// url to be opened when button is pressed
+        :param url: Optional. HTTP or tg:// url to be opened when the button is pressed.
+                    Links tg://user?id=<user_id> can be used to mention a user by their ID without using a username, if this is allowed by their privacy settings.
         :type  url: str|unicode
 
-        :param login_url: Optional. An HTTP URL used to automatically authorize the user. Can be used as a replacement for the Telegram Login Widget.
+        :param login_url: Optional. An HTTP URL used to automatically authorize the user.
+                          Can be used as a replacement for the Telegram Login Widget.
         :type  login_url: pytgbot.api_types.sendable.reply_markup.LoginUrl
 
-        :param callback_data: Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes
+        :param callback_data: Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes.
         :type  callback_data: str|unicode
 
-        :param switch_inline_query: Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field. Can be empty, in which case just the bot's username will be inserted.Note: This offers an easy way for users to start using your bot in inline mode when they are currently in a private chat with it. Especially useful when combined with switch_pm… actions – in this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
+        :param switch_inline_query: Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field.
+                                    Can be empty, in which case just the bot's username will be inserted.Note: This offers an easy way for users to start using your bot in inline mode when they are currently in a private chat with it.
+                                    Especially useful when combined with switch_pm… actions – in this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
         :type  switch_inline_query: str|unicode
 
-        :param switch_inline_query_current_chat: Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field. Can be empty, in which case only the bot's username will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat – good for selecting something from multiple options.
+        :param switch_inline_query_current_chat: Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field.
+                                                 Can be empty, in which case only the bot's username will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat – good for selecting something from multiple options.
         :type  switch_inline_query_current_chat: str|unicode
 
-        :param callback_game: Optional. Description of the game that will be launched when the user presses the button.NOTE: This type of button must always be the first button in the first row.
+        :param callback_game: Optional. Description of the game that will be launched when the user presses the button.
+                              NOTE: This type of button must always be the first button in the first row.
         :type  callback_game: pytgbot.api_types.receivable.updates.CallbackGame
 
-        :param pay: Optional. Specify True, to send a Pay button.NOTE: This type of button must always be the first button in the first row.
+        :param pay: Optional. Specify True, to send a Pay button.
+                    NOTE: This type of button must always be the first button in the first row and can only be used in invoice messages.
         :type  pay: bool
         """
         super(InlineKeyboardButton, self).__init__()
@@ -858,7 +900,6 @@ class InlineKeyboardButton(Button):
         if self.pay is not None:
             array['pay'] = bool(self.pay)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -953,7 +994,11 @@ class LoginUrl(Sendable):
     :param forward_text: Optional. New text of the button in forwarded messages.
     :type  forward_text: str|unicode
 
-    :param bot_username: Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.
+    :param bot_username: Optional. Username of a bot, which will be used for user authorization.
+                         See Setting up a bot for more details.
+                         If not specified, the current bot's username will be assumed.
+                         The url's domain must be the same as the domain linked with the bot.
+                         See Linking your domain to the bot for more details.
     :type  bot_username: str|unicode
 
     :param request_write_access: Optional. Pass True to request the permission for your bot to send messages to the user.
@@ -981,7 +1026,11 @@ class LoginUrl(Sendable):
         :param forward_text: Optional. New text of the button in forwarded messages.
         :type  forward_text: str|unicode
 
-        :param bot_username: Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.
+        :param bot_username: Optional. Username of a bot, which will be used for user authorization.
+                             See Setting up a bot for more details.
+                             If not specified, the current bot's username will be assumed.
+                             The url's domain must be the same as the domain linked with the bot.
+                             See Linking your domain to the bot for more details.
         :type  bot_username: str|unicode
 
         :param request_write_access: Optional. Pass True to request the permission for your bot to send messages to the user.
@@ -1024,7 +1073,6 @@ class LoginUrl(Sendable):
         if self.request_write_access is not None:
             array['request_write_access'] = bool(self.request_write_access)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -1119,11 +1167,15 @@ class ForceReply(ReplyMarkup):
 
     Optional keyword parameters:
 
-    :param selective: Optional. Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.
+    :param input_field_placeholder: Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters.
+    :type  input_field_placeholder: str|unicode
+
+    :param selective: Optional. Use this parameter if you want to force reply from specific users only.
+                      Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply (has reply_to_message_id), sender of the original message.
     :type  selective: bool
     """
 
-    def __init__(self, selective=None):
+    def __init__(self, input_field_placeholder=None, selective=None):
         """
         Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as
         if the user has selected the bot's message and tapped 'Reply').
@@ -1149,6 +1201,10 @@ class ForceReply(ReplyMarkup):
 
 
         Optional keyword parameters:
+
+        :param input_field_placeholder: Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters.
+        :type  input_field_placeholder: str|unicode
+
         :param selective: Optional. Use this parameter if you want to show the keyboard to/force reply from specific users only.
                           Targets: 1) users that are @mentioned in the text of the Message object;
                                    2) if the bot's message is a reply (has reply_to_message_id),
@@ -1160,6 +1216,8 @@ class ForceReply(ReplyMarkup):
         """
         super(ForceReply, self).__init__()
         self.force_reply = True
+        assert_type_or_raise(input_field_placeholder, None, unicode_type, parameter_name="input_field_placeholder")
+        self.input_field_placeholder = input_field_placeholder
         assert_type_or_raise(selective, None, bool, parameter_name="selective")
         self.selective = selective
     # end def __init__
@@ -1181,10 +1239,12 @@ class ForceReply(ReplyMarkup):
         array = super(ForceReply, self).to_array()
 
         array['force_reply'] = bool(self.force_reply)  # type bool
+        if self.input_field_placeholder is not None:
+            array['input_field_placeholder'] = u(self.input_field_placeholder)  # py2: type unicode, py3: type str
+        # end if
         if self.selective is not None:
             array['selective'] = bool(self.selective)  # type bool
         # end if
-
         return array
     # end def to_array
 
@@ -1199,6 +1259,7 @@ class ForceReply(ReplyMarkup):
         assert_type_or_raise(array, dict, parameter_name="array")
         data = ReplyMarkup.validate_array(array)
         # 'force_reply' is always True.
+        data['input_field_placeholder'] = u(array.get('input_field_placeholder')) if array.get('input_field_placeholder') is not None else None
         data['selective'] = bool(array.get('selective')) if array.get('selective') is not None else None
         return data
     # end def validate_array
@@ -1225,7 +1286,7 @@ class ForceReply(ReplyMarkup):
         """
         Implements `str(forcereply_instance)`
         """
-        return "ForceReply(force_reply={self.force_reply!r}, selective={self.selective!r})".format(self=self)
+        return "ForceReply(force_reply={self.force_reply!r}, input_field_placeholder={self.input_field_placeholder!r}, selective={self.selective!r})".format(self=self)
     # end def __str__
 
     def __repr__(self):
@@ -1235,7 +1296,7 @@ class ForceReply(ReplyMarkup):
         if self._raw:
             return "ForceReply.from_array({self._raw})".format(self=self)
         # end if
-        return "ForceReply(force_reply={self.force_reply!r}, selective={self.selective!r})".format(self=self)
+        return "ForceReply(force_reply={self.force_reply!r}, input_field_placeholder={self.input_field_placeholder!r}, selective={self.selective!r})".format(self=self)
     # end def __repr__
 
     def __contains__(self, key):
@@ -1243,7 +1304,7 @@ class ForceReply(ReplyMarkup):
         Implements `"key" in forcereply_instance`
         """
         return (
-            key in ["force_reply", "selective"]
+            key in ["force_reply", "input_field_placeholder", "selective"]
             and hasattr(self, key)
             and bool(getattr(self, key, None))
         )
